"use strict";
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.VsCodeKieEditorControllerFactory = void 0;
var vscode = require("vscode");
var vscode_1 = require("vscode");
var __path = require("path");
var api_1 = require("@kie-tools-core/editor/dist/api");
var VsCodeKieEditorController_1 = require("./VsCodeKieEditorController");
var VsCodeNodeResourceContentServiceImpl_1 = require("./VsCodeNodeResourceContentServiceImpl");
var VsCodeResourceContentServiceImpl_1 = require("./VsCodeResourceContentServiceImpl");
var VsCodeKieEditorChannelApiProducer_1 = require("./VsCodeKieEditorChannelApiProducer");
var VsCodeKieEditorControllerFactory = (function () {
    function VsCodeKieEditorControllerFactory(context, editorStore, editorEnvelopeLocator, messageBroadcaster, workspaceApi, backendProxy, notificationsApi, javaCodeCompletionApi, viewType, i18n, channelApiProducer) {
        if (channelApiProducer === void 0) { channelApiProducer = new VsCodeKieEditorChannelApiProducer_1.DefaultVsCodeEditorChannelApiProducer(); }
        this.context = context;
        this.editorStore = editorStore;
        this.editorEnvelopeLocator = editorEnvelopeLocator;
        this.messageBroadcaster = messageBroadcaster;
        this.workspaceApi = workspaceApi;
        this.backendProxy = backendProxy;
        this.notificationsApi = notificationsApi;
        this.javaCodeCompletionApi = javaCodeCompletionApi;
        this.viewType = viewType;
        this.i18n = i18n;
        this.channelApiProducer = channelApiProducer;
    }
    VsCodeKieEditorControllerFactory.prototype.configureNew = function (webviewPanel, document) {
        webviewPanel.webview.options = {
            enableCommandUris: true,
            enableScripts: true,
            localResourceRoots: [this.context.extensionUri],
        };
        var editorEnvelopeLocator = this.getEditorEnvelopeLocatorForWebview(webviewPanel.webview);
        var resourceContentService = this.createResourceContentService(document.document.uri.fsPath, vscode.workspace.asRelativePath(document.document.uri).replace(/\//g, __path.sep));
        var envelopeMapping = editorEnvelopeLocator.getEnvelopeMapping(document.document.uri.fsPath);
        if (!envelopeMapping) {
            throw new Error("No envelope mapping found for '".concat(document.document.uri, "'"));
        }
        var editor = new VsCodeKieEditorController_1.VsCodeKieEditorController(document, webviewPanel, this.context, this.editorStore, envelopeMapping, editorEnvelopeLocator, this.messageBroadcaster);
        var editorChannelApi = this.getChannelApi(editor, resourceContentService);
        this.editorStore.addAsActive(editor);
        editor.startListening(editorChannelApi);
        editor.startInitPolling(editorChannelApi);
        editor.setupPanelActiveStatusChange();
        editor.setupPanelOnDidDispose();
        editor.setupWebviewContent();
        editor.startListeningToThemeChanges();
        editor.startListeningToDocumentChanges();
    };
    VsCodeKieEditorControllerFactory.prototype.createResourceContentService = function (path, workspacePath) {
        if (this.isAssetInWorkspace(path)) {
            return new VsCodeResourceContentServiceImpl_1.VsCodeResourceContentServiceImpl(this.getParentFolder(workspacePath));
        }
        else {
            return new VsCodeNodeResourceContentServiceImpl_1.VsCodeNodeResourceContentServiceImpl(this.getParentFolder(path));
        }
    };
    VsCodeKieEditorControllerFactory.prototype.getChannelApi = function (editor, resourceContentService) {
        return this.channelApiProducer.get(editor, resourceContentService, this.workspaceApi, this.backendProxy, this.notificationsApi, this.javaCodeCompletionApi, this.viewType, this.i18n);
    };
    VsCodeKieEditorControllerFactory.prototype.getEditorEnvelopeLocatorForWebview = function (webview) {
        var _this = this;
        return new api_1.EditorEnvelopeLocator(this.editorEnvelopeLocator.targetOrigin, __spreadArray([], __read(this.editorEnvelopeLocator.envelopeMappings), false).reduce(function (envelopeMappings, mapping) {
            envelopeMappings.push(new api_1.EnvelopeMapping({
                type: mapping.type,
                filePathGlob: mapping.filePathGlob,
                resourcesPathPrefix: _this.getWebviewPath(webview, mapping.resourcesPathPrefix),
                envelopePath: _this.getWebviewPath(webview, mapping.envelopePath),
            }));
            return envelopeMappings;
        }, []));
    };
    VsCodeKieEditorControllerFactory.prototype.getWebviewPath = function (webview, relativePath) {
        return webview.asWebviewUri(vscode_1.Uri.joinPath(this.context.extensionUri, relativePath)).toString();
    };
    VsCodeKieEditorControllerFactory.prototype.isAssetInWorkspace = function (path) {
        var _a;
        return ((_a = vscode.workspace.workspaceFolders) === null || _a === void 0 ? void 0 : _a.map(function (f) { return f.uri.fsPath; }).find(function (p) { return path.startsWith(p); })) !== undefined;
    };
    VsCodeKieEditorControllerFactory.prototype.getParentFolder = function (assetPath) {
        if (assetPath.includes(__path.sep)) {
            return assetPath.substring(0, assetPath.lastIndexOf(__path.sep) + 1);
        }
        return "";
    };
    return VsCodeKieEditorControllerFactory;
}());
exports.VsCodeKieEditorControllerFactory = VsCodeKieEditorControllerFactory;
//# sourceMappingURL=VsCodeKieEditorControllerFactory.js.map